==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/File.java <==
package com.example.model;

/**
 * Model for File
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "File", description = "Model for File")
@javax.xml.bind.annotation.XmlRootElement(name = "File")
public class File implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String contentType = null;
	private java.lang.Integer size = null;
	private java.lang.String url = null;
	
	/**
	 */
	public File contentType(java.lang.String contentType) {
		setContentType(contentType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("content_type")
	@javax.validation.constraints.NotNull
	public java.lang.String getContentType() {
		return this.contentType;
	}
	public void setContentType(java.lang.String contentType) {
		this.contentType = contentType;
	}
	
	/**
	 */
	public File size(java.lang.Integer size) {
		setSize(size);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("size")
	public java.lang.Integer getSize() {
		return this.size;
	}
	public void setSize(java.lang.Integer size) {
		this.size = size;
	}
	
	/**
	 */
	public File url(java.lang.String url) {
		setUrl(url);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("url")
	public java.lang.String getUrl() {
		return this.url;
	}
	public void setUrl(java.lang.String url) {
		this.url = url;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		File file = (File) o;
		return java.util.Objects.equals(this.contentType, file.contentType)
				&& java.util.Objects.equals(this.size, file.size)
				&& java.util.Objects.equals(this.url, file.url);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.contentType, this.size, this.url);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class File {\n");
		
		sb.append("    contentType: ").append(toIndentedString(this.contentType)).append("\n");
		sb.append("    size: ").append(toIndentedString(this.size)).append("\n");
		sb.append("    url: ").append(toIndentedString(this.url)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/File.java <==
package com.example.model;

/**
 * Model for File
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "File", description = "Model for File")
@javax.xml.bind.annotation.XmlRootElement(name = "File")
public class File implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String contentType = null;
	private java.lang.Integer size = null;
	private java.lang.String url = null;
	
	/**
	 */
	public File contentType(java.lang.String contentType) {
		setContentType(contentType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "content_type")
	@com.fasterxml.jackson.annotation.JsonProperty("content_type")
	@javax.validation.constraints.NotNull
	public java.lang.String getContentType() {
		return this.contentType;
	}
	public void setContentType(java.lang.String contentType) {
		this.contentType = contentType;
	}
	
	/**
	 */
	public File size(java.lang.Integer size) {
		setSize(size);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "size")
	@com.fasterxml.jackson.annotation.JsonProperty("size")
	public java.lang.Integer getSize() {
		return this.size;
	}
	public void setSize(java.lang.Integer size) {
		this.size = size;
	}
	
	/**
	 */
	public File url(java.lang.String url) {
		setUrl(url);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "url")
	@com.fasterxml.jackson.annotation.JsonProperty("url")
	public java.lang.String getUrl() {
		return this.url;
	}
	public void setUrl(java.lang.String url) {
		this.url = url;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		File file = (File) o;
		return java.util.Objects.equals(this.contentType, file.contentType)
				&& java.util.Objects.equals(this.size, file.size)
				&& java.util.Objects.equals(this.url, file.url);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.contentType, this.size, this.url);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class File {\n");
		
		sb.append("    contentType: ").append(toIndentedString(this.contentType)).append("\n");
		sb.append("    size: ").append(toIndentedString(this.size)).append("\n");
		sb.append("    url: ").append(toIndentedString(this.url)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
